import { getInitialReplicationState } from '@resolve-js/eventstore-base';
import initReplicationStateTable from './init-replication-state-table';

const getReplicationState = async pool => {
  const {
    database,
    escapeId
  } = pool;
  const replicationStateTableName = await initReplicationStateTable(pool);
  const rows = await database.all(`SELECT "Status", "StatusData", "Iterator", "IsPaused", "SuccessEvent" FROM ${escapeId(replicationStateTableName)}`);

  if (rows.length > 0) {
    const row = rows[0];
    let lastEvent = null;

    if (row.SuccessEvent != null) {
      lastEvent = JSON.parse(row.SuccessEvent);
    }

    return {
      status: row.Status,
      statusData: row.StatusData != null ? JSON.parse(row.StatusData) : null,
      paused: row.IsPaused !== 0,
      iterator: row.Iterator != null ? JSON.parse(row.Iterator) : null,
      successEvent: lastEvent
    };
  } else {
    return getInitialReplicationState();
  }
};

export default getReplicationState;
//# sourceMappingURL=get-replication-state.js.map