"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

const loadSecrets = async ({
  database,
  escapeId,
  escape,
  secretsTableName
}, filter) => {
  const {
    idx,
    limit,
    skip,
    ids,
    includeDeleted
  } = filter;
  const tableNameAsId = escapeId(secretsTableName);
  const searchIdx = idx == null ? 0 : idx;
  const skipRows = skip === undefined ? 0 : skip;

  if (ids && ids.length === 0) {
    return {
      secrets: [],
      idx: searchIdx
    };
  }

  const rows = await database.all(`SELECT idx, id, secret FROM ${tableNameAsId}
    WHERE ${!includeDeleted ? `"secret" IS NOT NULL AND` : ''} idx >= ${+searchIdx}
    ${ids ? `AND id IN (${ids.map(id => escape(id)).join(',')})` : ''}
    ORDER BY "idx" ASC
    LIMIT ${+limit} OFFSET ${skipRows}`);
  const secrets = [];

  for (const secret of rows) {
    secrets.push({
      secret: secret.secret,
      id: secret.id,
      idx: secret.idx
    });
  }

  return {
    secrets: secrets,
    idx: secrets.length ? secrets[secrets.length - 1].idx + 1 : null
  };
};

var _default = loadSecrets;
exports.default = _default;
//# sourceMappingURL=load-secrets.js.map